<?
/***********************************************
* File	  :   config.php
* Project   :   Z-Push
* Descr	 :   Main configuration file
*
* Created   :   01.10.2007
*
*  Zarafa Deutschland GmbH, www.zarafaserver.de
* Some code  2010 Forget About IT Ltd. 
* This file is distributed under GPL v2.
* Consult LICENSE file for details
************************************************/
	// Defines the default time zone
	if (function_exists('date_default_timezone_set')){
		date_default_timezone_set('Europe/London');
	}

	// Defines the base path on the server, terminated by a slash
	define('BASE_PATH', dirname($_SERVER['SCRIPT_FILENAME']) . '/');

	// Define the include paths
	set_include_path(		 BASE_PATH. 'include/' . PATH_SEPARATOR .
					 BASE_PATH. PATH_SEPARATOR .
					 get_include_path());

	define('STATE_DIR', 'state');

	// Try to set unlimited timeout
	define('SCRIPT_TIMEOUT', 0);

	// The data provider that we are using (see configuration below)
	$BACKEND_PROVIDER = 'BackendCombined';

	// only allow login for these users
	// We could probably do an ldap group lookup here. If we are clever,
	// maybe we could use the user's own login to determine if they are in the group?
	// or maybe we just protect the whole directory with a different require-group directive.
	$ALLOWLOGIN = array();
	
	// deny login for these users
	// We could probably do an ldap group lookup here.
	$DENYLOGIN = array();

	// Device Provisioning
	define('PROVISIONING', true);



	
	// ************************
	//  BackendIMAP settings
	// ************************

	$BackendIMAP_config = array(
		// Defines the server to which we want to connect
		// recommended to use local servers only
		'IMAP_SERVER' => 'localhost',
		// connecting to default port (143)
		'IMAP_PORT' => 143,
		// best cross-platform compatibility (see http://php.net/imap_open for options)
		'IMAP_OPTIONS' => '/notls/norsh',
		//set which folders should have specific type
		'IMAP_FOLDERS' => array(
				SYNC_FOLDER_TYPE_INBOX => 'inbox',
				SYNC_FOLDER_TYPE_DRAFTS => array('drafts', 'inbox.drafts'),
				SYNC_FOLDER_TYPE_WASTEBASKET => array('trash', 'inbox.trash', 'wastebasket'),
				SYNC_FOLDER_TYPE_SENTMAIL => array( 'INBOX/Sent' ),
				SYNC_FOLDER_TYPE_OUTBOX => array('outbox'),
			),
		// overwrite the "from" header if it isn't set when sending emails
		// options: %u %d
		// %u
		// %u@domain.com
		// %u@%d
		'IMAP_FORCEFROM' => '%u',
	);
	
	// ****************************
	//  BackendFileStorage settings
	// ****************************

	$BackendFileStorage_config = array(
		'FILESTORAGE_DIR' => '/home/%u/FILES/PDA',
		//display name of the folder
		'FILESTORAGE_FOLDERNAME' => 'Files',
		'FILESTORAGE_DELIMITER' => '/',
		// files with these extensions are loaded in the body of the message
		'FILESTORAGE_BODYEXTS' => array(/*'txt', 'log', 'php'*/),
	);

	// ******************************
	//  BackendLDAP_Contacts settings
	// ******************************
	// %u is replaced by the username
	// New Contact Folder is where new contacts from PDA are created. Choice of 'PUBLIC' or 'PRIVATE' 

	$BackendLDAP_Contacts_config = array(
		# 'LDAP_SERVER' => 'ldap.example.com',
		'LDAP_SERVER' => 'localhost',
		'LDAP_DEFAULT_COUNTRY' => 'United Kingdom',
		'LDAP_USER_DN' => 'uid=%u,ou=People,dc=example,dc=com',
		'LDAP_PUBLIC_CONTACTS' => 'ou=AddressBook,dc=example,dc=com',
		'LDAP_PRIVATE_CONTACTS' => 'ou=AddressBook,uid=%u,ou=People,dc=example,dc=com',
		'LDAP_NEW_CONTACT_FOLDER' => 'PRIVATE', 
		);

	// ******************************
	//  BackendCalDAV settings
	// ******************************
	// %u is replaced by the username
	// Not yet implemented

	$BackendCalDAV_config = array(
		'CALDAV_BASE_URL' => 'https://caldav.example.com',
		'CALDAV_DEFAULT_CALENDAR' => 'home'
		);

	// *********************
	// BackendDummy settings
	// *********************

	$BackendDummy_config = array(
	    // empty array will allow every login
	    # 'DUMMY_LOGINS' => array(),
	    
	    // dummy folders to show
	    'DUMMY_FOLDERS' => array(
	#	    'inbox' => SYNC_FOLDER_TYPE_INBOX,
	#	    'drafts' => SYNC_FOLDER_TYPE_DRAFTS,
	#	    'waste' => SYNC_FOLDER_TYPE_WASTEBASKET,
	#	    'sent' => SYNC_FOLDER_TYPE_SENTMAIL,
	#	    'outbox' => SYNC_FOLDER_TYPE_OUTBOX
	    )
	);

	// *************************
	//  BackendCombined settings
	// *************************
	// Each type of backend must have a unique id.
	// This id is then used to link each folder type with a backend:
	// If you do not have a backend for a filetype, use the dummy
	// f = file
	// i = IMAP (or perhaps just mail)
	// d = dummy
	// v = contacts
	// s = serialize
	// r = rss
	
	$BackendCombined_config = array(
		//the order in which the backends are loaded.
		//login only succeeds if all backend return true on login
		//when sending mail: the mail is send with first backend that is able to send the mail
		'backends' => array(
			'f' => array(
				'name' => 'BackendFileStorage',
				'config' => $BackendFileStorage_config,
				'users' => array(
					'deviceusername' => array(
						'username'=>'backendusername',
						'password'=>'backendpassword',
						'domain' => 'backenddomain'
					),
				),
				'subfolder' => 'files',
			),
			'i' => array(
				'name' => 'BackendIMAP',
				'config' => $BackendIMAP_config,
			),
			'd' => array(
				'name' => 'BackendDummy',
				'config' => $BackendDummy_config
			),
			'v' => array(
				'name' => 'BackendLDAP_Contacts',
				'config' => $BackendLDAP_Contacts_config,
			),
//			's' => array(
//				'name' => 'BackendSerialize',
//				'config' => $BackendSerialize_config,
//			),
//			'r' => array(
//				'name' => 'BackendRSS',
//				'config' => $BackendRSS_config,
//			),
		),
		'delimiter' => '/',
		//force one type of folder to one backend
		'folderbackend' => array(
			SYNC_FOLDER_TYPE_INBOX => 'i',
			SYNC_FOLDER_TYPE_DRAFTS => 'i',
			SYNC_FOLDER_TYPE_WASTEBASKET => 'i',
			SYNC_FOLDER_TYPE_SENTMAIL => 'i',
			SYNC_FOLDER_TYPE_OUTBOX => 'i',
			SYNC_FOLDER_TYPE_TASK => 'd',
			SYNC_FOLDER_TYPE_APPOINTMENT => 'd',
			SYNC_FOLDER_TYPE_CONTACT => 'v',
			SYNC_FOLDER_TYPE_NOTE => 'd',
			SYNC_FOLDER_TYPE_JOURNAL => 'd',
		),
		//creating a new folder in the root folder should create a folder in one backend
		'rootcreatefolderbackend' => 'i',
	);

	eval('$BACKEND_CONFIG = $'.$BACKEND_PROVIDER.'_config;');
?>
